@@ -5,5 +5,5 @@ class Storage_Item:
         self.quantity = quantity
         self.isBlueprint = isBlueprint
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         return "Storage Item(name = {} | itemId = {} | quantity = {} | isBlueprint = {})".format(self.name, self.itemId, self.quantity, self.isBlueprint)
\ No newline at end of file
